@@ -1,29 +1,18 @@
 /*
-  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CONFIGUREPLUGINSWIDGET_H
-#define CONFIGUREPLUGINSWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include "pimcommon_export.h"
+#include <QWidget>
 class QSplitter;
 class QTextEdit;
-namespace PimCommon {
+class KMessageWidget;
+namespace PimCommon
+{
 class ConfigurePluginsListWidget;
 /**
  * @brief The ConfigurePluginsWidget class
@@ -35,7 +24,7 @@ class PIMCOMMON_EXPORT ConfigurePluginsWidget : public QWidget
 public:
     explicit ConfigurePluginsWidget(QWidget *parent = nullptr);
     explicit ConfigurePluginsWidget(ConfigurePluginsListWidget *configurePluginListWidget, QWidget *parent = nullptr);
-    ~ConfigurePluginsWidget();
+    ~ConfigurePluginsWidget() override;
 
     void save();
     void defaults();
@@ -49,11 +38,12 @@ private:
     void initialize();
     void readConfig();
     void writeConfig();
+    void slotConfigChanged();
     void initLayout(ConfigurePluginsListWidget *configurePluginListWidget = nullptr);
 
     QSplitter *mSplitter = nullptr;
     ConfigurePluginsListWidget *mConfigureListWidget = nullptr;
     QTextEdit *mDescription = nullptr;
+    KMessageWidget *mMessageWidget = nullptr;
 };
 }
-#endif // CONFIGUREPLUGINSWIDGET_H
