@@ -1,32 +1,34 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "templateeditdialog.h"
-#include <KPIMTextEdit/PlainTextEditorWidget>
 #include <KPIMTextEdit/PlainTextEditor>
+#include <KPIMTextEdit/PlainTextEditorWidget>
 #include <Libkdepim/LineEditCatchReturnKey>
 
 #include <KLocalizedString>
 #include <QLineEdit>
 
-#include <QVBoxLayout>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <KSharedConfig>
-#include <KConfigGroup>
-#include <QDialogButtonBox>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 
 TemplateEditDialog::TemplateEditDialog(QWidget *parent, bool defaultTemplate)
     : QDialog(parent)
+    , mTextEdit(new KPIMTextEdit::PlainTextEditorWidget(this))
+    , mTemplateNameEdit(new QLineEdit(this))
 {
-    setWindowTitle(defaultTemplate ? i18n("Default template") : i18n("Template"));
-    auto *mainLayout = new QVBoxLayout(this);
+    setWindowTitle(defaultTemplate ? i18nc("@title:window", "Default template") : i18nc("@title:window", "Template"));
+    auto mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = nullptr;
     if (defaultTemplate) {
         buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
@@ -40,18 +42,17 @@ TemplateEditDialog::TemplateEditDialog(QWidget *parent, bool defaultTemplate)
         connect(buttonBox, &QDialogButtonBox::rejected, this, &TemplateEditDialog::reject);
         mOkButton->setFocus();
     }
-    QWidget *w = new QWidget;
+    auto w = new QWidget;
     mainLayout->addWidget(w);
     mainLayout->addWidget(buttonBox);
 
-    auto *vbox = new QVBoxLayout;
-    vbox->setContentsMargins(0, 0, 0, 0);
+    auto vbox = new QVBoxLayout;
+    vbox->setContentsMargins({});
 
-    auto *hbox = new QHBoxLayout;
-    QLabel *label = new QLabel(i18n("Name:"));
+    auto hbox = new QHBoxLayout;
+    auto label = new QLabel(i18n("Name:"));
     hbox->addWidget(label);
 
-    mTemplateNameEdit = new QLineEdit;
     new KPIM::LineEditCatchReturnKey(mTemplateNameEdit, this);
     mTemplateNameEdit->setClearButtonEnabled(!defaultTemplate);
     mTemplateNameEdit->setReadOnly(defaultTemplate);
@@ -59,7 +60,6 @@ TemplateEditDialog::TemplateEditDialog(QWidget *parent, bool defaultTemplate)
 
     vbox->addLayout(hbox);
 
-    mTextEdit = new KPIMTextEdit::PlainTextEditorWidget;
     mTextEdit->setReadOnly(defaultTemplate);
     vbox->addWidget(mTextEdit);
 
@@ -82,13 +82,13 @@ TemplateEditDialog::~TemplateEditDialog()
 
 void TemplateEditDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "TemplateEditDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "TemplateEditDialog");
     group.writeEntry("Size", size());
 }
 
 void TemplateEditDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "TemplateEditDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "TemplateEditDialog");
     const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
