@@ -1,28 +1,16 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TEMPLATELISTWIDGET_H
-#define TEMPLATELISTWIDGET_H
+#pragma once
 
 #include "pimcommon_export.h"
 #include <QListWidget>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class TemplateListWidgetPrivate;
 
 struct defaultTemplate {
@@ -41,7 +29,7 @@ public:
     explicit TemplateListWidget(const QString &configName, QWidget *parent = nullptr);
     ~TemplateListWidget() override;
 
-    //Need to load template in specific class to allow to use correct defaultTemplates function
+    // Need to load template in specific class to allow to use correct defaultTemplates function
     void loadTemplates();
 
     Q_REQUIRED_RESULT virtual QVector<PimCommon::defaultTemplate> defaultTemplates();
@@ -54,12 +42,15 @@ public:
 
 protected:
     QStringList mimeTypes() const override;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QMimeData *mimeData(const QList<QListWidgetItem *> items) const override;
-
+#else
+    QMimeData *mimeData(const QList<QListWidgetItem *> &items) const override;
+#endif
     void dropEvent(QDropEvent *event) override;
     enum TemplateData {
         Text = Qt::UserRole + 1,
-        DefaultTemplate = Qt::UserRole + 2
+        DefaultTemplate = Qt::UserRole + 2,
     };
 
 Q_SIGNALS:
@@ -68,8 +59,7 @@ Q_SIGNALS:
 
 private:
     friend class TemplateListWidgetPrivate;
-    TemplateListWidgetPrivate *const d;
+    std::unique_ptr<TemplateListWidgetPrivate> const d;
 };
 }
 Q_DECLARE_TYPEINFO(PimCommon::defaultTemplate, Q_MOVABLE_TYPE);
-#endif // TEMPLATELISTWIDGET_H
