@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,15 +15,20 @@
 #include <QPushButton>
 #include <QVBoxLayout>
 
+namespace
+{
+const char myTranslatorDebugDialogConfigGroupName[] = "TranslatorDebugDialog";
+}
+
 TranslatorDebugDialog::TranslatorDebugDialog(QWidget *parent)
     : QDialog(parent)
     , mEdit(new KPIMTextEdit::PlainTextEditorWidget(this))
+    , mUser1Button(new QPushButton(this))
 {
     setWindowTitle(i18nc("@title:window", "Translator Debug"));
     auto mainLayout = new QVBoxLayout(this);
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
-    mUser1Button = new QPushButton(this);
     buttonBox->addButton(mUser1Button, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &TranslatorDebugDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &TranslatorDebugDialog::reject);
@@ -51,7 +56,7 @@ void TranslatorDebugDialog::setDebug(const QString &debugStr)
 
 void TranslatorDebugDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "TranslatorDebugDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myTranslatorDebugDialogConfigGroupName);
     const QSize sizeDialog = group.readEntry("Size", QSize(800, 600));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
@@ -60,7 +65,7 @@ void TranslatorDebugDialog::readConfig()
 
 void TranslatorDebugDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "TranslatorDebugDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myTranslatorDebugDialogConfigGroupName);
     group.writeEntry("Size", size());
 }
 
