@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,6 +26,5 @@ private:
     void readConfig();
     void writeConfig();
     KPIMTextEdit::PlainTextEditorWidget *const mEdit;
-    QPushButton *mUser1Button = nullptr;
+    QPushButton *const mUser1Button;
 };
-
