@@ -1,38 +1,23 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "customtreeview.h"
 
-#include <QPainter>
-#include <QFontDatabase>
 #include <QEvent>
+#include <QFontDatabase>
+#include <QPainter>
 
 using namespace PimCommon;
 
 CustomTreeView::CustomTreeView(QWidget *parent)
     : QTreeWidget(parent)
-    , mShowDefaultText(true)
 {
 }
 
-CustomTreeView::~CustomTreeView()
-{
-}
+CustomTreeView::~CustomTreeView() = default;
 
 void CustomTreeView::changeEvent(QEvent *event)
 {
