@@ -1,39 +1,28 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "customtoolswidgetng_gui.h"
-#include "customtools/customtoolswidgetng.h"
 #include "customtools/customtoolspluginmanager.h"
-#include <QStandardPaths>
+#include "customtools/customtoolswidgetng.h"
 #include <KToggleAction>
+#include <QStandardPaths>
 
-#include <QVBoxLayout>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QToolBar>
+#include <QVBoxLayout>
 
-#include <KXmlGui/kactioncollection.h>
+#include <KActionCollection>
 
 CustomToolWidgetNgTest::CustomToolWidgetNgTest(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
 
-    QToolBar *menu = new QToolBar(this);
+    auto menu = new QToolBar(this);
     lay->addWidget(menu);
 
     mCustomTools = new PimCommon::CustomToolsWidgetNg(this);
@@ -46,9 +35,7 @@ CustomToolWidgetNgTest::CustomToolWidgetNgTest(QWidget *parent)
     lay->addWidget(mCustomTools);
 }
 
-CustomToolWidgetNgTest::~CustomToolWidgetNgTest()
-{
-}
+CustomToolWidgetNgTest::~CustomToolWidgetNgTest() = default;
 
 int main(int argc, char **argv)
 {
@@ -59,7 +46,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    CustomToolWidgetNgTest *w = new CustomToolWidgetNgTest();
+    auto w = new CustomToolWidgetNgTest();
     w->resize(800, 200);
     w->show();
     const int ret = app.exec();
