@@ -1,25 +1,14 @@
 /*
-  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "imapaclattributetest.h"
 #include "../imapaclattribute.h"
 #include <QTest>
 
-typedef QMap<QByteArray, KIMAP::Acl::Rights> ImapAcl;
+using ImapAcl = QMap<QByteArray, KIMAP::Acl::Rights>;
 Q_DECLARE_METATYPE(ImapAcl)
 Q_DECLARE_METATYPE(KIMAP::Acl::Rights)
 
@@ -30,9 +19,7 @@ ImapAclAttributeTest::ImapAclAttributeTest(QObject *parent)
 {
 }
 
-ImapAclAttributeTest::~ImapAclAttributeTest()
-{
-}
+ImapAclAttributeTest::~ImapAclAttributeTest() = default;
 
 void ImapAclAttributeTest::shouldHaveDefaultValue()
 {
@@ -190,7 +177,8 @@ void ImapAclAttributeTest::testSerializeDeserialize_data()
     QTest::newRow("lookup") << acl << KIMAP::Acl::Rights(KIMAP::Acl::None) << QByteArray("user@host l %% ") << QByteArray("testme@host l %% user@host l");
 
     acl.insert("user@host", KIMAP::Acl::Lookup | KIMAP::Acl::Read);
-    QTest::newRow("lookup/read") << acl << KIMAP::Acl::Rights(KIMAP::Acl::None)  << QByteArray("user@host lr %% ") << QByteArray("testme@host l %% user@host lr");
+    QTest::newRow("lookup/read") << acl << KIMAP::Acl::Rights(KIMAP::Acl::None) << QByteArray("user@host lr %% ")
+                                 << QByteArray("testme@host l %% user@host lr");
 
     acl.insert("otheruser@host", KIMAP::Acl::Lookup | KIMAP::Acl::Read);
     QTest::newRow("lookup/read") << acl << KIMAP::Acl::Rights(KIMAP::Acl::None) << QByteArray("otheruser@host lr % user@host lr %% ")
@@ -207,7 +195,7 @@ void ImapAclAttributeTest::testSerializeDeserialize()
     QFETCH(QByteArray, serialized);
     QFETCH(QByteArray, oldSerialized);
 
-    ImapAclAttribute *attr = new ImapAclAttribute();
+    auto attr = new ImapAclAttribute();
     attr->setRights(rights);
     attr->setMyRights(myRights);
     QCOMPARE(attr->serialized(), serialized);
@@ -233,7 +221,7 @@ void ImapAclAttributeTest::testOldRights()
     acls.insert("second_user@host", KIMAP::Acl::Lookup | KIMAP::Acl::Read);
     acls.insert("third_user@host", KIMAP::Acl::Lookup | KIMAP::Acl::Read);
 
-    ImapAclAttribute *attr = new ImapAclAttribute();
+    auto attr = new ImapAclAttribute();
     attr->setRights(acls);
 
     ImapAcl oldAcls = acls;
