@@ -7,7 +7,7 @@
   SPDX-FileCopyrightText: 2001 Waldo Bastian <bastian@kde.org>
   SPDX-FileCopyrightText: 2004 Daniel Molkentin <danimo@klaralvdalens-datakonsult.se>
   SPDX-FileCopyrightText: 2004 Karl-Heinz Zimmer <khz@klaralvdalens-datakonsult.se>
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,14 +20,13 @@
 #include <KLDAP/LdapClientSearch>
 
 #include <KContacts/VCardConverter>
-#include <kcontacts_version.h>
 
 #include <Akonadi/Job>
 #include <KConfigGroup>
 #include <QUrl>
 
-#include <Akonadi/Contact/ContactGroupExpandJob>
-#include <Akonadi/Contact/ContactGroupSearchJob>
+#include <Akonadi/ContactGroupExpandJob>
+#include <Akonadi/ContactGroupSearchJob>
 #include <KColorScheme>
 #include <KContacts/ContactGroupTool>
 #include <KEmailAddress>
@@ -40,7 +39,7 @@
 #include <KLocalizedString>
 #include <KStandardShortcut>
 
-#include <ContactGroupExpandJob>
+#include <Akonadi/ContactGroupExpandJob>
 #include <KContacts/VCardDrag>
 #include <KMessageBox>
 #include <KSharedConfig>
@@ -79,7 +78,9 @@ AddresseeLineEdit::AddresseeLineEdit(QWidget *parent, bool enableCompletion)
     : KLineEdit(parent)
     , d(new AddresseeLineEditPrivate(this, enableCompletion))
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     setUrlDropsEnabled(false);
+#endif
 
     setObjectName(newLineEditObjectName());
     setPlaceholderText(QString());
@@ -299,13 +300,9 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
             // email-address.
             if (url.scheme() == QLatin1String("mailto")) {
                 KContacts::Addressee addressee;
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
-                addressee.insertEmail(KEmailAddress::decodeMailtoUrl(url), true /* preferred */);
-#else
                 KContacts::Email email(KEmailAddress::decodeMailtoUrl(url));
                 email.setPreferred(true);
                 addressee.addEmail(email);
-#endif
                 list += addressee;
             } else { // Otherwise, download the vCard to which the Url points
                 KContacts::VCardConverter converter;
@@ -387,13 +384,9 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
                             QUrl url(dropData);
                             if (url.scheme() == QLatin1String("mailto")) {
                                 KContacts::Addressee addressee;
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
-                                addressee.insertEmail(KEmailAddress::decodeMailtoUrl(url), true /* preferred */);
-#else
                                 KContacts::Email email(KEmailAddress::decodeMailtoUrl(url));
                                 email.setPreferred(true);
                                 addressee.addEmail(email);
-#endif
                                 insertEmails(addressee.emails());
                             } else {
                                 setText(KEmailAddress::normalizeAddressesAndDecodeIdn(dropData));
@@ -655,13 +648,9 @@ void AddresseeLineEdit::loadContacts()
                 name.chop(1);
             }
             addr.setNameFromString(name);
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
-            addr.insertEmail(emailString, true);
-#else
             KContacts::Email email(emailString);
             email.setPreferred(true);
             addr.addEmail(email);
-#endif
             addContact({emailString}, addr, weight, idx);
         }
     } else {
