@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,13 +10,18 @@
 #include "addresseelineeditldap.h"
 #include "kmailcompletion.h"
 
-#include <KLDAP/LdapClient>
-#include <QNetworkConfigurationManager>
-#include <QTimer>
-#include <QCoreApplication>
-#include <KConfigGroup>
-#include <KSharedConfig>
 #include <KColorScheme>
+#include <KConfigGroup>
+#include <KLDAP/LdapClient>
+#include <KSharedConfig>
+#include <QCoreApplication>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include "pimcommonakonadi_debug.h"
+#include <QNetworkInformation>
+#else
+#include <QNetworkConfigurationManager>
+#endif
+#include <QTimer>
 
 using namespace PimCommon;
 
@@ -27,7 +32,9 @@ AddresseeLineEditManager::AddresseeLineEditManager()
     , mAddresseeLineEditAkonadi(new AddresseeLineEditAkonadi)
     , mAddressessLineEditLdap(new AddresseeLineEditLdap(this))
     , mAddressessLineEditBaloo(new AddresseeLineEditBaloo)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     , mNetworkConfigMgr(new QNetworkConfigurationManager(QCoreApplication::instance()))
+#endif
 {
     KConfigGroup group(KSharedConfig::openConfig(), "AddressLineEdit");
     mShowOU = group.readEntry("ShowOU", false);
@@ -113,7 +120,16 @@ void AddresseeLineEditManager::setAddressLineEdit(AddresseeLineEdit *addressLine
 
 bool AddresseeLineEditManager::isOnline() const
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 1, 0)
+    if (QNetworkInformation::load(QNetworkInformation::Feature::Reachability)) {
+        return QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online;
+    } else {
+        qCWarning(PIMCOMMONAKONADI_LOG) << "Couldn't find a working backend for QNetworkInformation";
+        return false;
+    }
+#else
     return mNetworkConfigMgr->isOnline();
+#endif
 }
 
 KLDAP::LdapClientSearch *AddresseeLineEditManager::ldapSearch() const
