@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -20,9 +20,7 @@ BlackListBalooEmailCompletionWidgetTest::BlackListBalooEmailCompletionWidgetTest
 {
 }
 
-BlackListBalooEmailCompletionWidgetTest::~BlackListBalooEmailCompletionWidgetTest()
-{
-}
+BlackListBalooEmailCompletionWidgetTest::~BlackListBalooEmailCompletionWidgetTest() = default;
 
 void BlackListBalooEmailCompletionWidgetTest::shouldHaveDefaultValue()
 {
