@@ -1,12 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "blacklistbalooemaillist.h"
-#include "pimcommonakonadi_debug.h"
 
 #include <KEmailAddress>
 #include <KLocalizedString>
@@ -21,9 +20,7 @@ BlackListBalooEmailList::BlackListBalooEmailList(QWidget *parent)
     setSortingEnabled(true);
 }
 
-BlackListBalooEmailList::~BlackListBalooEmailList()
-{
-}
+BlackListBalooEmailList::~BlackListBalooEmailList() = default;
 
 void BlackListBalooEmailList::changeEvent(QEvent *event)
 {
@@ -133,9 +130,7 @@ BlackListBalooEmailListItem::BlackListBalooEmailListItem(QListWidget *parent)
     setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable);
 }
 
-BlackListBalooEmailListItem::~BlackListBalooEmailListItem()
-{
-}
+BlackListBalooEmailListItem::~BlackListBalooEmailListItem() = default;
 
 bool BlackListBalooEmailListItem::initializeStatus() const
 {
