@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -14,9 +14,7 @@ IncidencesForWidgetTest::IncidencesForWidgetTest(QObject *parent)
 {
 }
 
-IncidencesForWidgetTest::~IncidencesForWidgetTest()
-{
-}
+IncidencesForWidgetTest::~IncidencesForWidgetTest() = default;
 
 void IncidencesForWidgetTest::shouldHaveDefaultValue()
 {
