@@ -1,26 +1,14 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "selectmulticollectiondialog.h"
 #include "selectmulticollectionwidget.h"
 
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
 #include <QDialogButtonBox>
 #include <QPushButton>
@@ -31,9 +19,7 @@ using namespace PimCommon;
 class PimCommon::SelectMultiCollectionDialogPrivate
 {
 public:
-    SelectMultiCollectionDialogPrivate()
-    {
-    }
+    SelectMultiCollectionDialogPrivate() = default;
 
     SelectMultiCollectionWidget *mSelectMultiCollection = nullptr;
 };
@@ -55,14 +41,13 @@ SelectMultiCollectionDialog::SelectMultiCollectionDialog(const QString &mimetype
 SelectMultiCollectionDialog::~SelectMultiCollectionDialog()
 {
     writeConfig();
-    delete d;
 }
 
 void SelectMultiCollectionDialog::initialize(const QString &mimetype, const QList<Akonadi::Collection::Id> &selectedCollection)
 {
     setWindowTitle(i18nc("@title:window", "Select Multiple Folders"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
+    auto mainLayout = new QVBoxLayout(this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -77,7 +62,7 @@ void SelectMultiCollectionDialog::initialize(const QString &mimetype, const QLis
 
 void SelectMultiCollectionDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "SelectMultiCollectionDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "SelectMultiCollectionDialog");
     const QSize sizeDialog = group.readEntry("Size", QSize(800, 600));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
@@ -86,7 +71,7 @@ void SelectMultiCollectionDialog::readConfig()
 
 void SelectMultiCollectionDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "SelectMultiCollectionDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "SelectMultiCollectionDialog");
     group.writeEntry("Size", size());
 }
 
