@@ -1,24 +1,10 @@
 /*
  * This file is part of libkldap.
  *
- * Copyright (C) 2002 Klarälvdalens Datakonsult AB
+ * SPDX-FileCopyrightText: 2002 Klarälvdalens Datakonsult AB
+ * SPDX-FileContributor: Steffen Hansen <hansen@kde.org>
  *
- * Author: Steffen Hansen <hansen@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "ldapsearchdialog.h"
@@ -26,52 +12,55 @@
 #include <KLDAP/LdapClient>
 
 #include <KLDAP/LdapClientSearchConfig>
-#include <Libkdepim/ProgressIndicatorLabel>
+#include <KLDAP/LdapSearchClientReadConfigServerJob>
 #include <Libkdepim/LineEditCatchReturnKey>
+#include <Libkdepim/ProgressIndicatorLabel>
 
-#include <QPair>
 #include <QApplication>
 #include <QCheckBox>
+#include <QClipboard>
 #include <QCloseEvent>
 #include <QFrame>
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QHeaderView>
 #include <QLabel>
+#include <QMenu>
+#include <QPair>
+#include <QPointer>
 #include <QPushButton>
+#include <QSortFilterProxyModel>
 #include <QTableView>
 #include <QVBoxLayout>
-#include <QSortFilterProxyModel>
-#include <QMenu>
-#include <QClipboard>
 
-#include <QLineEdit>
-#include <QComboBox>
+#include <KCMultiDialog>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KCMultiDialog>
+#include <KMessageBox>
+#include <KPluginMetaData>
+#include <QComboBox>
 #include <QDialogButtonBox>
+#include <QLineEdit>
 #include <kldap/ldapobject.h>
 #include <kldap/ldapserver.h>
-#include <KMessageBox>
 
-#include <QLocale>
-#include <KLocalizedString>
 #include <KConfigGroup>
-#include <QDialogButtonBox>
 #include <KGuiItem>
+#include <KLocalizedString>
+#include <QDialogButtonBox>
+#include <QLocale>
 
 using namespace PimCommon;
 static QString asUtf8(const QByteArray &val)
 {
     if (val.isEmpty()) {
-        return QString();
+        return {};
     }
 
     const char *data = val.data();
 
-    //QString::fromUtf8() bug workaround
-    if (data[ val.size() - 1 ] == '\0') {
+    // QString::fromUtf8() bug workaround
+    if (data[val.size() - 1] == '\0') {
         return QString::fromUtf8(data, val.size() - 1);
     } else {
         return QString::fromUtf8(data, val.size());
@@ -81,14 +70,14 @@ static QString asUtf8(const QByteArray &val)
 static QString join(const KLDAP::LdapAttrValue &lst, const QString &sep)
 {
     QString res;
-    bool alredy = false;
+    bool already = false;
     KLDAP::LdapAttrValue::ConstIterator end(lst.constEnd());
     for (KLDAP::LdapAttrValue::ConstIterator it = lst.constBegin(); it != end; ++it) {
-        if (alredy) {
+        if (already) {
             res += sep;
         }
 
-        alredy = true;
+        already = true;
         res += asUtf8(*it);
     }
 
@@ -100,25 +89,25 @@ static QMap<QString, QString> &adrbookattr2ldap()
     static QMap<QString, QString> keys;
 
     if (keys.isEmpty()) {
-        keys[ i18nc("@item LDAP search key", "Title") ] = QStringLiteral("title");
-        keys[ i18n("Full Name") ] = QStringLiteral("cn");
-        keys[ i18nc("@item LDAP search key", "Email") ] = QStringLiteral("mail");
-        keys[ i18n("Home Number") ] = QStringLiteral("homePhone");
-        keys[ i18n("Work Number") ] = QStringLiteral("telephoneNumber");
-        keys[ i18n("Mobile Number") ] = QStringLiteral("mobile");
-        keys[ i18n("Fax Number") ] = QStringLiteral("facsimileTelephoneNumber");
-        keys[ i18n("Pager") ] = QStringLiteral("pager");
-        keys[ i18n("Street") ] = QStringLiteral("street");
-        keys[ i18nc("@item LDAP search key", "State") ] = QStringLiteral("st");
-        keys[ i18n("Country") ] = QStringLiteral("co");
-        keys[ i18n("City") ] = QStringLiteral("l");   //krazy:exclude=doublequote_chars
-        keys[ i18n("Organization") ] = QStringLiteral("o");   //krazy:exclude=doublequote_chars
-        keys[ i18n("Company") ] = QStringLiteral("Company");
-        keys[ i18n("Department") ] = QStringLiteral("department");
-        keys[ i18n("Zip Code") ] = QStringLiteral("postalCode");
-        keys[ i18n("Postal Address") ] = QStringLiteral("postalAddress");
-        keys[ i18n("Description") ] = QStringLiteral("description");
-        keys[ i18n("User ID") ] = QStringLiteral("uid");
+        keys[i18nc("@item LDAP search key", "Title")] = QStringLiteral("title");
+        keys[i18n("Full Name")] = QStringLiteral("cn");
+        keys[i18nc("@item LDAP search key", "Email")] = QStringLiteral("mail");
+        keys[i18n("Home Number")] = QStringLiteral("homePhone");
+        keys[i18n("Work Number")] = QStringLiteral("telephoneNumber");
+        keys[i18n("Mobile Number")] = QStringLiteral("mobile");
+        keys[i18n("Fax Number")] = QStringLiteral("facsimileTelephoneNumber");
+        keys[i18n("Pager")] = QStringLiteral("pager");
+        keys[i18n("Street")] = QStringLiteral("street");
+        keys[i18nc("@item LDAP search key", "State")] = QStringLiteral("st");
+        keys[i18n("Country")] = QStringLiteral("co");
+        keys[i18n("City")] = QStringLiteral("l"); // krazy:exclude=doublequote_chars
+        keys[i18n("Organization")] = QStringLiteral("o"); // krazy:exclude=doublequote_chars
+        keys[i18n("Company")] = QStringLiteral("Company");
+        keys[i18n("Department")] = QStringLiteral("department");
+        keys[i18n("Zip Code")] = QStringLiteral("postalCode");
+        keys[i18n("Postal Address")] = QStringLiteral("postalAddress");
+        keys[i18n("Description")] = QStringLiteral("description");
+        keys[i18n("User ID")] = QStringLiteral("uid");
     }
 
     return keys;
@@ -127,11 +116,11 @@ static QMap<QString, QString> &adrbookattr2ldap()
 static QString makeFilter(const QString &query, LdapSearchDialog::FilterType attr, bool startsWith)
 {
     /* The reasoning behind this filter is:
-    * If it's a person, or a distlist, show it, even if it doesn't have an email address.
-    * If it's not a person, or a distlist, only show it if it has an email attribute.
-    * This allows both resource accounts with an email address which are not a person and
-    * person entries without an email address to show up, while still not showing things
-    * like structural entries in the ldap tree. */
+     * If it's a person, or a distlist, show it, even if it doesn't have an email address.
+     * If it's not a person, or a distlist, only show it if it has an email attribute.
+     * This allows both resource accounts with an email address which are not a person and
+     * person entries without an email address to show up, while still not showing things
+     * like structural entries in the ldap tree. */
     QString result(QStringLiteral("&(|(objectclass=person)(objectclass=groupofnames)(mail=*))("));
     if (query.isEmpty()) {
         // Return a filter that matches everything
@@ -173,23 +162,25 @@ static KContacts::Addressee convertLdapAttributesToAddressee(const KLDAP::LdapAt
     KLDAP::LdapAttrValue::ConstIterator it = lst.constBegin();
     bool pref = true;
     while (it != lst.constEnd()) {
-        addr.insertEmail(asUtf8(*it), pref);
+        KContacts::Email email(asUtf8(*it));
+        email.setPreferred(pref);
+        addr.addEmail(email);
         pref = false;
         ++it;
     }
 
     if (!attrs.value(QStringLiteral("o")).isEmpty()) {
-        addr.setOrganization(asUtf8(attrs[ QStringLiteral("o") ].first()));
+        addr.setOrganization(asUtf8(attrs[QStringLiteral("o")].first()));
     }
     if (addr.organization().isEmpty() && !attrs.value(QStringLiteral("Company")).isEmpty()) {
-        addr.setOrganization(asUtf8(attrs[ QStringLiteral("Company") ].first()));
+        addr.setOrganization(asUtf8(attrs[QStringLiteral("Company")].first()));
     }
 
     // Address
     KContacts::Address workAddr(KContacts::Address::Work);
 
     if (!attrs.value(QStringLiteral("department")).isEmpty()) {
-        addr.setDepartment(asUtf8(attrs[ QStringLiteral("department") ].first()));
+        addr.setDepartment(asUtf8(attrs[QStringLiteral("department")].first()));
     }
 
     if (!workAddr.isEmpty()) {
@@ -198,31 +189,31 @@ static KContacts::Addressee convertLdapAttributesToAddressee(const KLDAP::LdapAt
 
     // phone
     if (!attrs.value(QStringLiteral("homePhone")).isEmpty()) {
-        KContacts::PhoneNumber homeNr = asUtf8(attrs[  QStringLiteral("homePhone") ].first());
+        KContacts::PhoneNumber homeNr = asUtf8(attrs[QStringLiteral("homePhone")].first());
         homeNr.setType(KContacts::PhoneNumber::Home);
         addr.insertPhoneNumber(homeNr);
     }
 
     if (!attrs.value(QStringLiteral("telephoneNumber")).isEmpty()) {
-        KContacts::PhoneNumber workNr = asUtf8(attrs[  QStringLiteral("telephoneNumber") ].first());
+        KContacts::PhoneNumber workNr = asUtf8(attrs[QStringLiteral("telephoneNumber")].first());
         workNr.setType(KContacts::PhoneNumber::Work);
         addr.insertPhoneNumber(workNr);
     }
 
     if (!attrs.value(QStringLiteral("facsimileTelephoneNumber")).isEmpty()) {
-        KContacts::PhoneNumber faxNr = asUtf8(attrs[  QStringLiteral("facsimileTelephoneNumber") ].first());
+        KContacts::PhoneNumber faxNr = asUtf8(attrs[QStringLiteral("facsimileTelephoneNumber")].first());
         faxNr.setType(KContacts::PhoneNumber::Fax);
         addr.insertPhoneNumber(faxNr);
     }
 
     if (!attrs.value(QStringLiteral("mobile")).isEmpty()) {
-        KContacts::PhoneNumber cellNr = asUtf8(attrs[  QStringLiteral("mobile") ].first());
+        KContacts::PhoneNumber cellNr = asUtf8(attrs[QStringLiteral("mobile")].first());
         cellNr.setType(KContacts::PhoneNumber::Cell);
         addr.insertPhoneNumber(cellNr);
     }
 
     if (!attrs.value(QStringLiteral("pager")).isEmpty()) {
-        KContacts::PhoneNumber pagerNr = asUtf8(attrs[  QStringLiteral("pager") ].first());
+        KContacts::PhoneNumber pagerNr = asUtf8(attrs[QStringLiteral("pager")].first());
         pagerNr.setType(KContacts::PhoneNumber::Pager);
         addr.insertPhoneNumber(pagerNr);
     }
@@ -233,9 +224,7 @@ static KContacts::Addressee convertLdapAttributesToAddressee(const KLDAP::LdapAt
 class ContactListModel : public QAbstractTableModel
 {
 public:
-    enum Role {
-        ServerRole = Qt::UserRole + 1
-    };
+    enum Role { ServerRole = Qt::UserRole + 1 };
 
     explicit ContactListModel(QObject *parent)
         : QAbstractTableModel(parent)
@@ -250,7 +239,7 @@ public:
         endResetModel();
     }
 
-    QPair<KLDAP::LdapAttrMap, QString> contact(const QModelIndex &index) const
+    Q_REQUIRED_RESULT QPair<KLDAP::LdapAttrMap, QString> contact(const QModelIndex &index) const
     {
         if (!index.isValid() || index.row() < 0 || index.row() >= mContactList.count()) {
             return qMakePair(KLDAP::LdapAttrMap(), QString());
@@ -259,19 +248,19 @@ public:
         return qMakePair(mContactList.at(index.row()), mServerList.at(index.row()));
     }
 
-    QString email(const QModelIndex &index) const
+    Q_REQUIRED_RESULT QString email(const QModelIndex &index) const
     {
         if (!index.isValid() || index.row() < 0 || index.row() >= mContactList.count()) {
-            return QString();
+            return {};
         }
 
         return asUtf8(mContactList.at(index.row()).value(QStringLiteral("mail")).first()).trimmed();
     }
 
-    QString fullName(const QModelIndex &index) const
+    Q_REQUIRED_RESULT QString fullName(const QModelIndex &index) const
     {
         if (!index.isValid() || index.row() < 0 || index.row() >= mContactList.count()) {
-            return QString();
+            return {};
         }
 
         return asUtf8(mContactList.at(index.row()).value(QStringLiteral("cn")).first()).trimmed();
@@ -285,7 +274,7 @@ public:
         endResetModel();
     }
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const override
+    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (!parent.isValid()) {
             return mContactList.count();
@@ -294,7 +283,7 @@ public:
         }
     }
 
-    int columnCount(const QModelIndex &parent = QModelIndex()) const override
+    Q_REQUIRED_RESULT int columnCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (!parent.isValid()) {
             return 18;
@@ -303,10 +292,10 @@ public:
         }
     }
 
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
+    Q_REQUIRED_RESULT QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
     {
         if (orientation == Qt::Vertical || role != Qt::DisplayRole || section < 0 || section > 17) {
-            return QVariant();
+            return {};
         }
 
         switch (section) {
@@ -329,8 +318,7 @@ public:
         case 8:
             return i18n("Street");
         case 9:
-            return i18nc("@title:column Column containing the residential state of the address",
-                         "State");
+            return i18nc("@title:column Column containing the residential state of the address", "State");
         case 10:
             return i18n("Country");
         case 11:
@@ -348,19 +336,18 @@ public:
         case 17:
             return i18nc("@title:column Column containing title of the person", "Title");
         default:
-            return QVariant();
+            return {};
         }
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
+    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (!index.isValid()) {
-            return QVariant();
+            return {};
         }
 
-        if (index.row() < 0 || index.row() >= mContactList.count()
-            || index.column() < 0 || index.column() > 17) {
-            return QVariant();
+        if (index.row() < 0 || index.row() >= mContactList.count() || index.column() < 0 || index.column() > 17) {
+            return {};
         }
 
         if (role == ServerRole) {
@@ -368,7 +355,7 @@ public:
         }
 
         if ((role != Qt::DisplayRole) && (role != Qt::ToolTipRole)) {
-            return QVariant();
+            return {};
         }
 
         const KLDAP::LdapAttrMap map = mContactList.at(index.row());
@@ -411,7 +398,7 @@ public:
         case 17:
             return join(map.value(QStringLiteral("title")), QStringLiteral(", "));
         default:
-            return QVariant();
+            return {};
         }
     }
 
@@ -420,17 +407,17 @@ private:
     QStringList mServerList;
 };
 
-class Q_DECL_HIDDEN LdapSearchDialog::Private
+class Q_DECL_HIDDEN LdapSearchDialog::LdapSearchDialogPrivate
 {
 public:
-    Private(LdapSearchDialog *qq)
+    LdapSearchDialogPrivate(LdapSearchDialog *qq)
         : q(qq)
     {
     }
 
-    QList< QPair<KLDAP::LdapAttrMap, QString> > selectedItems()
+    QVector<QPair<KLDAP::LdapAttrMap, QString>> selectedItems()
     {
-        QList< QPair<KLDAP::LdapAttrMap, QString> > contacts;
+        QVector<QPair<KLDAP::LdapAttrMap, QString>> contacts;
 
         const QModelIndexList selected = mResultView->selectionModel()->selectedRows();
         const int numberOfSelectedElement(selected.count());
@@ -456,7 +443,7 @@ public:
     void slotUnselectAll();
     void slotSelectionChanged();
 
-    LdapSearchDialog *q;
+    LdapSearchDialog *const q;
     KGuiItem startSearchGuiItem;
     KGuiItem stopSearchGuiItem;
     int mNumHosts = 0;
@@ -480,16 +467,16 @@ public:
 
 LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     : QDialog(parent)
-    , d(new Private(this))
+    , d(new LdapSearchDialogPrivate(this))
 {
     setWindowTitle(i18nc("@title:window", "Import Contacts from LDAP"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel, this);
     d->user1Button = new QPushButton;
     buttonBox->addButton(d->user1Button, QDialogButtonBox::ActionRole);
 
-    QPushButton *user2Button = new QPushButton;
+    auto user2Button = new QPushButton;
     buttonBox->addButton(user2Button, QDialogButtonBox::ActionRole);
 
     connect(d->user1Button, &QPushButton::clicked, this, &LdapSearchDialog::slotUser1);
@@ -498,20 +485,19 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->user1Button->setDefault(true);
     setModal(false);
     KGuiItem::assign(buttonBox->button(QDialogButtonBox::Cancel), KStandardGuiItem::close());
-    QFrame *page = new QFrame(this);
+    auto page = new QFrame(this);
     mainLayout->addWidget(page);
     mainLayout->addWidget(buttonBox);
 
-    QVBoxLayout *topLayout = new QVBoxLayout(page);
-    topLayout->setContentsMargins(0, 0, 0, 0);
+    auto topLayout = new QVBoxLayout(page);
+    topLayout->setContentsMargins({});
 
-    QGroupBox *groupBox = new QGroupBox(i18n("Search for Addresses in Directory"),
-                                        page);
-    QGridLayout *boxLayout = new QGridLayout();
+    auto groupBox = new QGroupBox(i18n("Search for Addresses in Directory"), page);
+    auto boxLayout = new QGridLayout();
     groupBox->setLayout(boxLayout);
     boxLayout->setColumnStretch(1, 1);
 
-    QLabel *label = new QLabel(i18n("Search for:"), groupBox);
+    auto label = new QLabel(i18n("Search for:"), groupBox);
     boxLayout->addWidget(label, 0, 0);
 
     d->mSearchEdit = new QLineEdit(groupBox);
@@ -555,7 +541,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
 
     topLayout->addWidget(groupBox);
 
-    QHBoxLayout *quickSearchLineLayout = new QHBoxLayout;
+    auto quickSearchLineLayout = new QHBoxLayout;
     quickSearchLineLayout->addStretch();
     d->searchLine = new QLineEdit;
     new KPIM::LineEditCatchReturnKey(d->searchLine, this);
@@ -570,7 +556,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->mModel = new ContactListModel(d->mResultView);
 
     d->sortproxy = new QSortFilterProxyModel(this);
-    d->sortproxy->setFilterKeyColumn(-1); //Search in all column
+    d->sortproxy->setFilterKeyColumn(-1); // Search in all column
     d->sortproxy->setSourceModel(d->mModel);
     d->sortproxy->setFilterCaseSensitivity(Qt::CaseInsensitive);
     connect(d->searchLine, &QLineEdit::textChanged, d->sortproxy, &QSortFilterProxyModel::setFilterFixedString);
@@ -579,7 +565,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->mResultView->verticalHeader()->hide();
     d->mResultView->setSortingEnabled(true);
     d->mResultView->horizontalHeader()->setSortIndicatorShown(true);
-    connect(d->mResultView, qOverload<const QModelIndex &>(&QTableView::clicked), this, [this]() {
+    connect(d->mResultView, &QTableView::clicked, this, [this]() {
         d->slotSelectionChanged();
     });
     topLayout->addWidget(d->mResultView);
@@ -587,21 +573,19 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->mResultView->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(d->mResultView, &QTableView::customContextMenuRequested, this, &LdapSearchDialog::slotCustomContextMenuRequested);
 
-    QHBoxLayout *buttonLayout = new QHBoxLayout;
-    buttonLayout->setContentsMargins(0, 0, 0, 0);
+    auto buttonLayout = new QHBoxLayout;
+    buttonLayout->setContentsMargins({});
     topLayout->addLayout(buttonLayout);
 
     d->progressIndication = new KPIM::ProgressIndicatorLabel(i18n("Searching..."));
     buttonLayout->addWidget(d->progressIndication);
 
-    QDialogButtonBox *buttons = new QDialogButtonBox(page);
-    QPushButton *button = buttons->addButton(i18n("Select All"),
-                                             QDialogButtonBox::ActionRole);
+    auto buttons = new QDialogButtonBox(page);
+    QPushButton *button = buttons->addButton(i18n("Select All"), QDialogButtonBox::ActionRole);
     connect(button, &QPushButton::clicked, this, [this]() {
         d->slotSelectAll();
     });
-    button = buttons->addButton(i18n("Unselect All"),
-                                QDialogButtonBox::ActionRole);
+    button = buttons->addButton(i18n("Unselect All"), QDialogButtonBox::ActionRole);
     connect(button, &QPushButton::clicked, this, [this]() {
         d->slotUnselectAll();
     });
@@ -611,12 +595,10 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     d->user1Button->setText(i18n("Add Selected"));
     user2Button->setText(i18n("Configure LDAP Servers..."));
 
-    connect(d->mRecursiveCheckbox, &QCheckBox::toggled,
-            this, [this](bool state) {
+    connect(d->mRecursiveCheckbox, &QCheckBox::toggled, this, [this](bool state) {
         d->slotSetScope(state);
     });
-    connect(d->mSearchButton, SIGNAL(clicked()),
-            this, SLOT(slotStartSearch()));
+    connect(d->mSearchButton, SIGNAL(clicked()), this, SLOT(slotStartSearch()));
 
     setTabOrder(d->mSearchEdit, d->mFilterCombo);
     setTabOrder(d->mFilterCombo, d->mSearchButton);
@@ -629,7 +611,6 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
 LdapSearchDialog::~LdapSearchDialog()
 {
     d->saveSettings();
-    delete d;
 }
 
 void LdapSearchDialog::setSearchText(const QString &text)
@@ -655,12 +636,12 @@ void LdapSearchDialog::slotCustomContextMenuRequested(const QPoint &pos)
     }
 }
 
-void LdapSearchDialog::Private::slotSelectionChanged()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotSelectionChanged()
 {
     user1Button->setEnabled(mResultView->selectionModel()->hasSelection());
 }
 
-void LdapSearchDialog::Private::restoreSettings()
+void LdapSearchDialog::LdapSearchDialogPrivate::restoreSettings()
 {
     // Create one KLDAP::LdapClient per selected server and configure it.
 
@@ -682,23 +663,27 @@ void LdapSearchDialog::Private::restoreSettings()
         mIsConfigured = false;
     } else {
         mIsConfigured = true;
-        KLDAP::LdapClientSearchConfig *clientSearchConfig = new KLDAP::LdapClientSearchConfig;
+        auto clientSearchConfig = new KLDAP::LdapClientSearchConfig;
         for (int j = 0; j < mNumHosts; ++j) {
-            KLDAP::LdapServer ldapServer;
-            KLDAP::LdapClient *ldapClient = new KLDAP::LdapClient(0, q);
-            clientSearchConfig->readConfig(ldapServer, group, j, true);
-            ldapClient->setServer(ldapServer);
+            auto ldapClient = new KLDAP::LdapClient(0, q);
+            auto job = new KLDAP::LdapSearchClientReadConfigServerJob(q);
+            job->setCurrentIndex(j);
+            job->setActive(true);
+            job->setConfig(group);
+            job->setLdapClient(ldapClient);
+            job->start();
             QStringList attrs;
 
             QMap<QString, QString>::ConstIterator end(adrbookattr2ldap().constEnd());
-            for (QMap<QString, QString>::ConstIterator it = adrbookattr2ldap().constBegin();
-                 it != end; ++it) {
+            for (QMap<QString, QString>::ConstIterator it = adrbookattr2ldap().constBegin(); it != end; ++it) {
                 attrs << *it;
             }
 
             ldapClient->setAttributes(attrs);
 
+            // clang-format off
             q->connect(ldapClient, SIGNAL(result(KLDAP::LdapClient,KLDAP::LdapObject)), q, SLOT(slotAddResult(KLDAP::LdapClient,KLDAP::LdapObject)));
+            // clang-format on
             q->connect(ldapClient, SIGNAL(done()), q, SLOT(slotSearchDone()));
             q->connect(ldapClient, &KLDAP::LdapClient::error, q, [this](const QString &err) {
                 slotError(err);
@@ -722,7 +707,7 @@ void LdapSearchDialog::Private::restoreSettings()
     }
 }
 
-void LdapSearchDialog::Private::saveSettings()
+void LdapSearchDialog::LdapSearchDialogPrivate::saveSettings()
 {
     KConfig *config = KLDAP::LdapClientSearchConfig::config();
     KConfigGroup group(config, "LDAPSearch");
@@ -739,21 +724,21 @@ void LdapSearchDialog::Private::saveSettings()
     group.sync();
 }
 
-void LdapSearchDialog::Private::cancelQuery()
+void LdapSearchDialog::LdapSearchDialogPrivate::cancelQuery()
 {
-    for (KLDAP::LdapClient *client : qAsConst(mLdapClientList)) {
+    for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
         client->cancelQuery();
     }
 }
 
-void LdapSearchDialog::Private::slotAddResult(const KLDAP::LdapClient &client, const KLDAP::LdapObject &obj)
+void LdapSearchDialog::LdapSearchDialogPrivate::slotAddResult(const KLDAP::LdapClient &client, const KLDAP::LdapObject &obj)
 {
     mModel->addContact(obj.attributes(), client.server().host());
 }
 
-void LdapSearchDialog::Private::slotSetScope(bool rec)
+void LdapSearchDialog::LdapSearchDialogPrivate::slotSetScope(bool rec)
 {
-    for (KLDAP::LdapClient *client : qAsConst(mLdapClientList)) {
+    for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
         if (rec) {
             client->setScope(QStringLiteral("sub"));
         } else {
@@ -762,7 +747,7 @@ void LdapSearchDialog::Private::slotSetScope(bool rec)
     }
 }
 
-void LdapSearchDialog::Private::slotStartSearch()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotStartSearch()
 {
     cancelQuery();
 
@@ -783,28 +768,27 @@ void LdapSearchDialog::Private::slotStartSearch()
 
     const bool startsWith = (mSearchType->currentIndex() == 1);
 
-    const QString filter = makeFilter(mSearchEdit->text().trimmed(),
-                                      mFilterCombo->currentData().value<FilterType>(), startsWith);
+    const QString filter = makeFilter(mSearchEdit->text().trimmed(), mFilterCombo->currentData().value<FilterType>(), startsWith);
 
     // loop in the list and run the KLDAP::LdapClients
     mModel->clear();
-    for (KLDAP::LdapClient *client : qAsConst(mLdapClientList)) {
+    for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
         client->startQuery(filter);
     }
 
     saveSettings();
 }
 
-void LdapSearchDialog::Private::slotStopSearch()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotStopSearch()
 {
     cancelQuery();
     slotSearchDone();
 }
 
-void LdapSearchDialog::Private::slotSearchDone()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotSearchDone()
 {
     // If there are no more active clients, we are done.
-    for (KLDAP::LdapClient *client : qAsConst(mLdapClientList)) {
+    for (KLDAP::LdapClient *client : std::as_const(mLdapClientList)) {
         if (client->isActive()) {
             return;
         }
@@ -820,7 +804,7 @@ void LdapSearchDialog::Private::slotSearchDone()
 #endif
 }
 
-void LdapSearchDialog::Private::slotError(const QString &error)
+void LdapSearchDialog::LdapSearchDialogPrivate::slotError(const QString &error)
 {
 #ifndef QT_NO_CURSOR
     QApplication::restoreOverrideCursor();
@@ -834,13 +818,13 @@ void LdapSearchDialog::closeEvent(QCloseEvent *e)
     e->accept();
 }
 
-void LdapSearchDialog::Private::slotUnselectAll()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotUnselectAll()
 {
     mResultView->clearSelection();
     slotSelectionChanged();
 }
 
-void LdapSearchDialog::Private::slotSelectAll()
+void LdapSearchDialog::LdapSearchDialogPrivate::slotSelectAll()
 {
     mResultView->selectAll();
     slotSelectionChanged();
@@ -852,7 +836,7 @@ void LdapSearchDialog::slotUser1()
 
     d->mSelectedContacts.clear();
 
-    const QList< QPair<KLDAP::LdapAttrMap, QString> > &items = d->selectedItems();
+    const QVector<QPair<KLDAP::LdapAttrMap, QString>> &items = d->selectedItems();
 
     if (!items.isEmpty()) {
         const QDateTime now = QDateTime::currentDateTime();
@@ -863,7 +847,8 @@ void LdapSearchDialog::slotUser1()
             // set a comment where the contact came from
             contact.setNote(i18nc("arguments are host name, datetime",
                                   "Imported from LDAP directory %1 on %2",
-                                  items.at(i).second, QLocale().toString(now, QLocale::ShortFormat)));
+                                  items.at(i).second,
+                                  QLocale().toString(now, QLocale::ShortFormat)));
 
             d->mSelectedContacts.append(contact);
         }
@@ -881,9 +866,9 @@ void LdapSearchDialog::slotUser2()
 
     QPointer<KCMultiDialog> dialog = new KCMultiDialog(this);
     dialog->setWindowTitle(i18nc("@title:window", "Configure the Address Book LDAP Settings"));
-    dialog->addModule(QStringLiteral("kcmldap.desktop"));
+    dialog->addModule(KPluginMetaData(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kcms/kaddressbook/kcm_ldap")));
 
-    if (dialog->exec()) {   //krazy:exclude=crashy
+    if (dialog->exec()) { // krazy:exclude=crashy
         d->restoreSettings();
     }
     delete dialog;
